pub fn init()Expand description
Initialize the WASM module.
This sets up panic hooks for better error messages in the browser console. Call this once before using any other functions.
pub fn init()Initialize the WASM module.
This sets up panic hooks for better error messages in the browser console. Call this once before using any other functions.